Apis class

Properties

actionModelApi ↔ ActionModelApi?
getter/setter pair
coreApi ↔ CoreApi?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mediumApi ↔ MediumApi?
getter/setter pair
registryApi ↔ RegistryApi?
getter/setter pair
routerApi ↔ RouterApi?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wizardApi ↔ WizardApi?
getter/setter pair

Methods

getActionModelApi() → ActionModelApi
getCoreApi() → CoreApi
getMediumApi() → MediumApi
getRegistryApi() → RegistryApi
getRouterApi() → RouterApi
getWizardApi() → WizardApi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerActionModelApi(ActionModelApi actionModelApi) → void
registerCoreApi(CoreApi coreApi) → void
registerMediumApi(MediumApi mediumApi) → void
registerRegistryApi(RegistryApi registryApi) → void
registerRouterApi(RouterApi routerApi) → void
registerWizardApi(WizardApi wizardApi) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

apis() → Apis