HasSplit class abstract

Implementers

Constructors

HasSplit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splitView(AppModel app, BuildContext context, Widget container1, Widget container2, double ratio, double minRatio, double maxRatio) → Widget
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited