ActionSpecification class

Constructors

ActionSpecification({required bool requiresAccessToLocalFileSystem, required bool availableInLeftDrawer, required bool availableInRightDrawer, required bool availableInAppBar, required bool availableInHomeMenu, required bool available})

Properties

available ↔ bool
getter/setter pair
availableInAppBar ↔ bool
getter/setter pair
availableInHomeMenu ↔ bool
getter/setter pair
availableInLeftDrawer ↔ bool
getter/setter pair
availableInRightDrawer ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requiresAccessToLocalFileSystem ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
should(MenuType type) → bool
shouldCreatePageDialogOrWorkflow() → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited