PublicMediumEntity class

Constructors

PublicMediumEntity({required String? authorId, String? base, String? ext, String? url, String? ref, String? urlThumbnail, String? refThumbnail, int? mediumType, int? mediumWidth, int? mediumHeight, int? thumbnailWidth, int? thumbnailHeight, String? relatedMediumId})

Properties

authorId → String?
final
base → String?
final
ext → String?
final
hashCode → int
The hash code for this object.
no setterinherited
mediumHeight → int?
final
mediumType → int?
final
mediumWidth → int?
final
props → List<Object?>
no setter
ref → String?
final
refThumbnail → String?
final
relatedMediumId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight → int?
final
thumbnailWidth → int?
final
url → String?
final
urlThumbnail → String?
final

Methods

copyWith({String? documentID, String? authorId, String? base, String? ext, String? url, String? ref, String? urlThumbnail, String? refThumbnail, int? mediumType, int? mediumWidth, int? mediumHeight, int? thumbnailWidth, int? thumbnailHeight, String? relatedMediumId}) → PublicMediumEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → PublicMediumEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → PublicMediumEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → PublicMediumEntity?