RgbEntity class

Constructors

RgbEntity({int? r, int? g, int? b, double? opacity})

Properties

b → int?
final
g → int?
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → double?
final
props → List<Object?>
no setter
r → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? r, int? g, int? b, double? opacity}) → RgbEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → RgbEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → RgbEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → RgbEntity?