RgbModel class

Constructors

RgbModel({int? r, int? g, int? b, double? opacity})

Properties

b ↔ int?
getter/setter pair
g ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
opacity ↔ double?
getter/setter pair
r ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
copyWith({int? r, int? g, int? b, double? opacity}) → RgbModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → RgbEntity
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(RgbEntity? entity) → Future<RgbModel?>
fromEntityPlus(RgbEntity? entity, {String? appId}) → Future<RgbModel?>

Constants

id → const String
packageName → const String