UserRepository class

Constructors

UserRepository({FirebaseAuth? firebaseAuth, GoogleSignIn? googleSignin})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

currentSignedinUser() → User?
getUser() → String?
isSignedIn() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
profilePhoto() → String?
signInWithApple() → Future<User?>
signInWithAppleOnApple() → Future<User>
signInWithAppleOnWeb() → Future<User>
signInWithGoogle() → Future<User?>
signInWithProvider() → Future<User>
signOut() → Future<List<void>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited