UploadInfo class

Constructors

UploadInfo(String url, String ref)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ref → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

uploadData(String baseName, Uint8List fileData, String appId, String ownerId, String packageName, Map<String, String> customMetaData, {FeedbackProgress? feedbackProgress}) → Future<UploadInfo?>
uploadFile(String memberMediumDocumentID, String filePath, String appId, String ownerId, String packageName, Map<String, String> customMetaData, {String? homeURL, FeedbackProgress? feedbackProgress}) → Future<Tuple2<UploadInfo, Uint8List>>
uploadTempData(Uint8List fileData, String appId, String ownerId, String packageName, Map<String, String> customMetaData, {FeedbackProgress? feedbackProgress}) → Future<UploadInfo?>